Skip to contents

Calculates the estimate of total biomass and abundance using the swept area. Variance of the estimate is also calculated. Requires the outputs from both the stratprep and stratmean functions.

Usage

swept_area(
  prepData,
  stratmeanData,
  q = NULL,
  a = 0.0384,
  areaDescription,
  groupDescription = "SVSPP"
)

Arguments

prepData

NEFSC survey data generated by Survdat.R and modified by stratprep().

stratmeanData

Output from strat_mean().

q

Table of survey catchability with a column of group names and a column of catchabilities. If not provided, assumes a q of 1 for each group (Minimum swept area estimates).

a

The average swept area of the trawl. Default value is the swept area of a standard NOAA Ship Albatross IV tow.

areaDescription

Column of survdat containing strata designations.

groupDescription

Column of survdat upon which the totals are based (i.e. SVSPP).

Value

Returns a table with the estimates of total biomass and abundance as well as the stratified mean biomass and abundance for each group indicated by the groupDescription parameter. In addition, the variance of the totals and variance and standard error for both means are provided.

See also

Examples

if (FALSE) { # \dontrun{
# Called internally
} # }