Assign survey data (points, lat and lon) to designated regions (polygons) from a shape file.
Arguments
- surveyData
Data table. NEFSC survey data generated by
get_survdat_data.R- areaPolygon
sf object or character string. Default = "NEFSC strata". The default option uses the survey strata shapefile bundled with the package. To use any other shapefile for stratification, the shapefile must be read in as an sf object and the
areaDescriptionargument must be specified.- areaDescription
Character String. Column name from
areaPolygonthat contains the strata designations.- na.keep
Boolean. Logical value to indicate whether original strata names should be retained.
Value
Returns a surveyData data.table with one additional column labeled
with the value of areaDescription
- areaDescription
The name of the region (found in
areaPolygon) that a record insurveyDatais assigned to
See also
Other internal:
strat_mean(),
strat_prep(),
swept_area()